@@ -9,7 +9,7 @@ onecor.wtd <- function(x, y, weight=NULL){
     weight <- weight[use]
     #r1 <- lm(stdz(y, weight=weight)~stdz(x, weight=weight), weight=weight)
     #corcoef <- coef(summary(r1))[2,]
-    corcoef <- coef(summary(lm(stdz(y, weight=weight)~stdz(x, weight=weight), weight=weight)))[2,]
+    corcoef <- coef(summary(lm(stdz(y, weight=weight)~stdz(x, weight=weight), weights=weight)))[2,]
   }
   else
     corcoef <- rep(NA, 4)
